#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-prettyprint
version:              0.1.1.0
visibility:           public
id:                   rio-prettyprint-0.1.1.0-4kcKQiTdqrH2SHiI4Ucw43
key:                  rio-prettyprint-0.1.1.0-4kcKQiTdqrH2SHiI4Ucw43
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  59f44d1ebecf62a3659ba8b6e47bef40
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-8.10.3/site-local/rio-prettyprint-0.1.1.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/rio-prettyprint-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.3/rio-prettyprint-0.1.1.0
hs-libraries:         HSrio-prettyprint-0.1.1.0-4kcKQiTdqrH2SHiI4Ucw43
depends:
    Cabal-3.2.1.0 aeson-1.5.5.1-9jeVsPSyrWB7SomB2C4Dbq
    annotated-wl-pprint-0.7.0-HXu68S9Nys8Hg2W61VXV5e
    ansi-terminal-0.11-2SXi8ZhU18i2uWLidRUotS array-0.5.4.0
    base-4.14.1.0 colour-2.3.5-C29WD8Qg69AL3qeQgayHy7 mtl-2.2.2
    path-0.8.0-7heFkhncrSTDEqYwDMG3OT
    rio-0.1.20.0-B8NTxB6eSMbJYS9eWZ794V text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

